
#ifndef __EB_GSTSRC_H__
#define __EB_GSTSRC_H__

#ifdef ENABLE_GSTREAMER

G_BEGIN_DECLS

#define EB_GST_TYPE_SRC                  (eb_gst_src_get_type())
#define EB_GST_SRC(obj)                  (G_TYPE_CHECK_INSTANCE_CAST ((obj), EB_GST_TYPE_SRC, EbGstSrc))
#define EB_GST_IS_SRC(obj)               (G_TYPE_CHECK_INSTANCE_TYPE ((obj), EB_GST_TYPE_SRC))
#define EB_GST_SRC_CLASS(klass)          (G_TYPE_CHECK_CLASS_CAST ((klass), EB_GST_TYPE_SRC, EbGstSrcClass))
#define EB_GST_IS_SRC_CLASS(klass)       (G_TYPE_CHECK_CLASS_TYPE ((klass), EB_GST_TYPE_SRC))
#define EB_GST_SRC_GET_CLASS(obj)        (G_TYPE_INSTANCE_GET_CLASS ((obj), EB_GST_TYPE_SRC, EbGstSrcClass))

typedef struct _EbGstSrc        EbGstSrc;
typedef struct _EbGstSrcClass   EbGstSrcClass;

struct _EbGstSrc
{
    GstBaseSrc parent_instance;

    /* instance members */
    RESULT  *res;
};

struct _EbGstSrcClass
{
    GstBaseSrcClass parent_class;

    /* class members */
};

GType eb_gst_src_get_type(void);

G_END_DECLS

#endif /* GSTREAMER */
#endif /* __EB_GSTSRC_H__ */
